UnsupportedRouteException class

Exception thrown when a route cannot be handled by compatibility layer and must be pushed using native Navigator.

This is used internally by YxNavigator to detect routes that should bypass compatibility overrides (e.g., PopupMenuRoute).

Implemented types

Constructors

UnsupportedRouteException(Route<Object?> route, String message)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
route Route<Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited