yx_navigation_flutter_compatibility library
Optional Navigator 1.0 compatibility shims, observers, and route adapters.
Import this library only when you are migrating legacy imperative navigation code side by side with the declarative router.
Classes
- BackButtonListenableRouter
- A wrapper widget that handles system back button events for root Router.
- CompatibilityObserver
- Observer for monitoring Navigator 1.0 compatibility layer events.
- CustomRoutePageFactoryResolver
- Interface for custom handling of specific Route types that are not supported out of the box by NavigatorCompatibilityOverrides.
- Central component of the compatibility layer that adapts Navigator 1.0 operations for use with YxNavigation's declarative architecture.
Extensions
- RouteNodeCompatibilityExtension on RouteNode
-
Extension on
RouteNodethat provides compatibility layer utilities for distinguishing between page-based and pageless routes.
Exceptions / Errors
- UnsupportedRouteException
- Exception thrown when a route cannot be handled by compatibility layer and must be pushed using native Navigator.