hasResolverFor<T> abstract method
Determines whether this resolver can handle the given route.
Return true if this resolver knows how to create a Page for
the provided route type. Return false otherwise.
This method is called for every route created via Navigator 1.0 API to determine if custom handling is needed.
Example
@override
bool hasResolverFor<T>(Route<T> route) {
// Handle specific route types
return route is MyCustomRoute || route is ThirdPartyRoute;
}
Implementation
bool hasResolverFor<T>(Route<T> route);